@@ -18,13 +18,15 @@ Implementation Notes
 """
 
 # imports
+from __future__ import annotations
+
 try:
     from typing import Sequence
     import usb_hid
 except ImportError:
     pass
 
-__version__ = "5.3.2"
+__version__ = "5.3.3"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_HID.git"
 
 
@@ -34,7 +36,7 @@ def find_device(
     """Search through the provided sequence of devices to find the one with the matching
     usage_page and usage."""
     if hasattr(devices, "send_report"):
-        devices = [devices]
+        devices = [devices]  # type: ignore
     for device in devices:
         if (
             device.usage_page == usage_page
